aboutsummaryrefslogtreecommitdiffstats
path: root/examples/corelib/tools/regexp.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/corelib/tools/regexp.py')
-rw-r--r--examples/corelib/tools/regexp.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/corelib/tools/regexp.py b/examples/corelib/tools/regexp.py
index 3a953329a..48c03309e 100644
--- a/examples/corelib/tools/regexp.py
+++ b/examples/corelib/tools/regexp.py
@@ -40,9 +40,9 @@
##
#############################################################################
-"""PySide2 port of the widgets/tools/regexp example from Qt v5.x"""
+"""PySide6 port of the widgets/tools/regexp example from Qt v5.x"""
-from PySide2 import QtCore, QtGui, QtWidgets
+from PySide6 import QtCore, QtGui, QtWidgets
class RegExpDialog(QtWidgets.QDialog):